@@ -6,7 +6,9 @@
 #' cite_easystats()
 #' summary(cite_easystats())
 #' as.data.frame(cite_easystats())
-#' @return An object of class `cite_easystats` that can be printed, summarized (using `summary()`), or transformed into a table (using `as.data.frame()`).
+#'
+#' @return An object of class `cite_easystats` that can be printed, summarized
+#'   (using `summary()`), or transformed into a table (using `as.data.frame()`).
 #'
 #' @export
 cite_easystats <- function() {
@@ -103,7 +105,13 @@ cite_easystats <- function() {
   }
   "
 
-  out <- list(intro = intro, intext = intext, refs = refs, table = table, bib = bib)
+  out <- list(
+    intro = intro,
+    intext = intext,
+    refs = refs,
+    table = table,
+    bib = bib
+  )
 
   class(out) <- c("cite_easystats", class(out))
   out
